# PyQt Spell check

## Usage

### Setup

- Install [enchant](https://github.com/AbiWord/enchant)

- Install from PyPI

```shell
$ pip install pyqt-spellcheck
```

### Example

An example of usage is available in `examples/example.py`

<img src="https://i.imgur.com/VSo625R.gif" width="500" height="500" alt="Demo"/>
